package com.link.core.objeccache;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.google.common.cache.CacheBuilder;
import com.google.common.cache.CacheLoader;
import com.google.common.cache.LoadingCache;
import com.link.base.cacheconfig.model.CacheConfig;
import com.link.base.cacheconfig.service.CacheConfigServiceImpl;
import com.link.core.util.RedisUtil;
import com.link.core.util.SpringUtil;
import com.link.core.util.StringUtils;
import com.link.core.util.redisclient.LinkRedisClient;
import java.time.Duration;
import java.util.List;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ObjectConfigCache {
   private static final Logger logger = LoggerFactory.getLogger(ObjectConfigCache.class);
   private static LoadingCache<String, JSONArray> objectConfigCache = CacheBuilder.newBuilder().initialCapacity(1).maximumSize(1L).expireAfterWrite(Duration.ofDays(1L)).build(new CacheLoader<String, JSONArray>() {
      public JSONArray load(String key) throws Exception {
         LinkRedisClient redisClient = null;

         String configStr;
         try {
            redisClient = RedisUtil.getJedis();
            String cacheConfigStr = redisClient.get("CacheConfigKey");
            if (!StringUtils.isBlank(cacheConfigStr)) {
               JSONArray var11 = JSONArray.parseArray(cacheConfigStr);
               return var11;
            }

            CacheConfig cacheConfig;
            if (redisClient.exists("CacheConfigKey")) {
               cacheConfig = null;
               return cacheConfig;
            }

            cacheConfig = new CacheConfig();
            cacheConfig.setCorpid(0L);
            List<CacheConfig> configList = ((CacheConfigServiceImpl)SpringUtil.getBean(CacheConfigServiceImpl.class)).queryAll(cacheConfig);
            if (configList.size() >= 1) {
               configStr = JSONObject.toJSONString(configList);
               redisClient.set("CacheConfigKey", configStr);
               JSONArray var7 = JSONArray.parseArray(configStr);
               return var7;
            }

            configStr = null;
         } finally {
            RedisUtil.returnResource(redisClient);
         }

         return configStr;
      }
   });

   public static JSONArray getObjectConfigCache() throws Exception {
      JSONArray jsonArray = (JSONArray)objectConfigCache.get("CacheConfigKey");
      if (jsonArray != null && jsonArray.size() >= 1) {
         return jsonArray;
      } else {
         Class var1 = ObjectConfigCache.class;
         synchronized(ObjectConfigCache.class) {
            if (jsonArray == null || jsonArray.size() < 1) {
               invalidateObjectConfigCache();
            }
         }

         throw new Exception("未查询到缓存配置");
      }
   }

   public static void refreshObjectConfigCache() throws Exception {
      objectConfigCache.refresh("CacheConfigKey");
   }

   public static void invalidateObjectConfigCache() {
      objectConfigCache.invalidate("CacheConfigKey");
   }
}
